# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ThemeArgs', 'Theme']

@pulumi.input_type
class ThemeArgs:
    def __init__(__self__, *,
                 brand_id: pulumi.Input[_builtins.str],
                 background_image: Optional[pulumi.Input[_builtins.str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 favicon: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 theme_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Theme resource.
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] background_image: Path to local file
        :param pulumi.Input[_builtins.str] email_template_touch_point_variant: Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[_builtins.str] end_user_dashboard_touch_point_variant: Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[_builtins.str] error_page_touch_point_variant: Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] favicon: Path to local file
        :param pulumi.Input[_builtins.str] logo: Path to local file
        :param pulumi.Input[_builtins.str] primary_color_contrast_hex: Primary color contrast hex code
        :param pulumi.Input[_builtins.str] primary_color_hex: Primary color hex code
        :param pulumi.Input[_builtins.str] secondary_color_contrast_hex: Secondary color contrast hex code
        :param pulumi.Input[_builtins.str] secondary_color_hex: Secondary color hex code
        :param pulumi.Input[_builtins.str] sign_in_page_touch_point_variant: Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] theme_id: Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        pulumi.set(__self__, "brand_id", brand_id)
        if background_image is not None:
            pulumi.set(__self__, "background_image", background_image)
        if email_template_touch_point_variant is not None:
            pulumi.set(__self__, "email_template_touch_point_variant", email_template_touch_point_variant)
        if end_user_dashboard_touch_point_variant is not None:
            pulumi.set(__self__, "end_user_dashboard_touch_point_variant", end_user_dashboard_touch_point_variant)
        if error_page_touch_point_variant is not None:
            pulumi.set(__self__, "error_page_touch_point_variant", error_page_touch_point_variant)
        if favicon is not None:
            pulumi.set(__self__, "favicon", favicon)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if primary_color_contrast_hex is not None:
            pulumi.set(__self__, "primary_color_contrast_hex", primary_color_contrast_hex)
        if primary_color_hex is not None:
            pulumi.set(__self__, "primary_color_hex", primary_color_hex)
        if secondary_color_contrast_hex is not None:
            pulumi.set(__self__, "secondary_color_contrast_hex", secondary_color_contrast_hex)
        if secondary_color_hex is not None:
            pulumi.set(__self__, "secondary_color_hex", secondary_color_hex)
        if sign_in_page_touch_point_variant is not None:
            pulumi.set(__self__, "sign_in_page_touch_point_variant", sign_in_page_touch_point_variant)
        if theme_id is not None:
            pulumi.set(__self__, "theme_id", theme_id)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Input[_builtins.str]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="backgroundImage")
    def background_image(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "background_image")

    @background_image.setter
    def background_image(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "background_image", value)

    @_builtins.property
    @pulumi.getter(name="emailTemplateTouchPointVariant")
    def email_template_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        """
        return pulumi.get(self, "email_template_touch_point_variant")

    @email_template_touch_point_variant.setter
    def email_template_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_template_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter(name="endUserDashboardTouchPointVariant")
    def end_user_dashboard_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        """
        return pulumi.get(self, "end_user_dashboard_touch_point_variant")

    @end_user_dashboard_touch_point_variant.setter
    def end_user_dashboard_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_user_dashboard_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter(name="errorPageTouchPointVariant")
    def error_page_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "error_page_touch_point_variant")

    @error_page_touch_point_variant.setter
    def error_page_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "error_page_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter
    def favicon(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "favicon")

    @favicon.setter
    def favicon(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "favicon", value)

    @_builtins.property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logo", value)

    @_builtins.property
    @pulumi.getter(name="primaryColorContrastHex")
    def primary_color_contrast_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Primary color contrast hex code
        """
        return pulumi.get(self, "primary_color_contrast_hex")

    @primary_color_contrast_hex.setter
    def primary_color_contrast_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_color_contrast_hex", value)

    @_builtins.property
    @pulumi.getter(name="primaryColorHex")
    def primary_color_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Primary color hex code
        """
        return pulumi.get(self, "primary_color_hex")

    @primary_color_hex.setter
    def primary_color_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_color_hex", value)

    @_builtins.property
    @pulumi.getter(name="secondaryColorContrastHex")
    def secondary_color_contrast_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secondary color contrast hex code
        """
        return pulumi.get(self, "secondary_color_contrast_hex")

    @secondary_color_contrast_hex.setter
    def secondary_color_contrast_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_color_contrast_hex", value)

    @_builtins.property
    @pulumi.getter(name="secondaryColorHex")
    def secondary_color_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secondary color hex code
        """
        return pulumi.get(self, "secondary_color_hex")

    @secondary_color_hex.setter
    def secondary_color_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_color_hex", value)

    @_builtins.property
    @pulumi.getter(name="signInPageTouchPointVariant")
    def sign_in_page_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "sign_in_page_touch_point_variant")

    @sign_in_page_touch_point_variant.setter
    def sign_in_page_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_in_page_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        return pulumi.get(self, "theme_id")

    @theme_id.setter
    def theme_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "theme_id", value)


@pulumi.input_type
class _ThemeState:
    def __init__(__self__, *,
                 background_image: Optional[pulumi.Input[_builtins.str]] = None,
                 background_image_url: Optional[pulumi.Input[_builtins.str]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 favicon: Optional[pulumi.Input[_builtins.str]] = None,
                 favicon_url: Optional[pulumi.Input[_builtins.str]] = None,
                 links: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 logo_url: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 theme_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Theme resources.
        :param pulumi.Input[_builtins.str] background_image: Path to local file
        :param pulumi.Input[_builtins.str] background_image_url: Background image URL
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] email_template_touch_point_variant: Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[_builtins.str] end_user_dashboard_touch_point_variant: Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[_builtins.str] error_page_touch_point_variant: Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] favicon: Path to local file
        :param pulumi.Input[_builtins.str] favicon_url: Favicon URL
        :param pulumi.Input[_builtins.str] links: Link relations for this object - JSON HAL - Discoverable resources related to the email template
        :param pulumi.Input[_builtins.str] logo: Path to local file
        :param pulumi.Input[_builtins.str] logo_url: Logo URL
        :param pulumi.Input[_builtins.str] primary_color_contrast_hex: Primary color contrast hex code
        :param pulumi.Input[_builtins.str] primary_color_hex: Primary color hex code
        :param pulumi.Input[_builtins.str] secondary_color_contrast_hex: Secondary color contrast hex code
        :param pulumi.Input[_builtins.str] secondary_color_hex: Secondary color hex code
        :param pulumi.Input[_builtins.str] sign_in_page_touch_point_variant: Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] theme_id: Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        if background_image is not None:
            pulumi.set(__self__, "background_image", background_image)
        if background_image_url is not None:
            pulumi.set(__self__, "background_image_url", background_image_url)
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if email_template_touch_point_variant is not None:
            pulumi.set(__self__, "email_template_touch_point_variant", email_template_touch_point_variant)
        if end_user_dashboard_touch_point_variant is not None:
            pulumi.set(__self__, "end_user_dashboard_touch_point_variant", end_user_dashboard_touch_point_variant)
        if error_page_touch_point_variant is not None:
            pulumi.set(__self__, "error_page_touch_point_variant", error_page_touch_point_variant)
        if favicon is not None:
            pulumi.set(__self__, "favicon", favicon)
        if favicon_url is not None:
            pulumi.set(__self__, "favicon_url", favicon_url)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if logo is not None:
            pulumi.set(__self__, "logo", logo)
        if logo_url is not None:
            pulumi.set(__self__, "logo_url", logo_url)
        if primary_color_contrast_hex is not None:
            pulumi.set(__self__, "primary_color_contrast_hex", primary_color_contrast_hex)
        if primary_color_hex is not None:
            pulumi.set(__self__, "primary_color_hex", primary_color_hex)
        if secondary_color_contrast_hex is not None:
            pulumi.set(__self__, "secondary_color_contrast_hex", secondary_color_contrast_hex)
        if secondary_color_hex is not None:
            pulumi.set(__self__, "secondary_color_hex", secondary_color_hex)
        if sign_in_page_touch_point_variant is not None:
            pulumi.set(__self__, "sign_in_page_touch_point_variant", sign_in_page_touch_point_variant)
        if theme_id is not None:
            pulumi.set(__self__, "theme_id", theme_id)

    @_builtins.property
    @pulumi.getter(name="backgroundImage")
    def background_image(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "background_image")

    @background_image.setter
    def background_image(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "background_image", value)

    @_builtins.property
    @pulumi.getter(name="backgroundImageUrl")
    def background_image_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Background image URL
        """
        return pulumi.get(self, "background_image_url")

    @background_image_url.setter
    def background_image_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "background_image_url", value)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "brand_id", value)

    @_builtins.property
    @pulumi.getter(name="emailTemplateTouchPointVariant")
    def email_template_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        """
        return pulumi.get(self, "email_template_touch_point_variant")

    @email_template_touch_point_variant.setter
    def email_template_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_template_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter(name="endUserDashboardTouchPointVariant")
    def end_user_dashboard_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        """
        return pulumi.get(self, "end_user_dashboard_touch_point_variant")

    @end_user_dashboard_touch_point_variant.setter
    def end_user_dashboard_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_user_dashboard_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter(name="errorPageTouchPointVariant")
    def error_page_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "error_page_touch_point_variant")

    @error_page_touch_point_variant.setter
    def error_page_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "error_page_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter
    def favicon(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "favicon")

    @favicon.setter
    def favicon(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "favicon", value)

    @_builtins.property
    @pulumi.getter(name="faviconUrl")
    def favicon_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Favicon URL
        """
        return pulumi.get(self, "favicon_url")

    @favicon_url.setter
    def favicon_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "favicon_url", value)

    @_builtins.property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the email template
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "links", value)

    @_builtins.property
    @pulumi.getter
    def logo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "logo")

    @logo.setter
    def logo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logo", value)

    @_builtins.property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Logo URL
        """
        return pulumi.get(self, "logo_url")

    @logo_url.setter
    def logo_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logo_url", value)

    @_builtins.property
    @pulumi.getter(name="primaryColorContrastHex")
    def primary_color_contrast_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Primary color contrast hex code
        """
        return pulumi.get(self, "primary_color_contrast_hex")

    @primary_color_contrast_hex.setter
    def primary_color_contrast_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_color_contrast_hex", value)

    @_builtins.property
    @pulumi.getter(name="primaryColorHex")
    def primary_color_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Primary color hex code
        """
        return pulumi.get(self, "primary_color_hex")

    @primary_color_hex.setter
    def primary_color_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "primary_color_hex", value)

    @_builtins.property
    @pulumi.getter(name="secondaryColorContrastHex")
    def secondary_color_contrast_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secondary color contrast hex code
        """
        return pulumi.get(self, "secondary_color_contrast_hex")

    @secondary_color_contrast_hex.setter
    def secondary_color_contrast_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_color_contrast_hex", value)

    @_builtins.property
    @pulumi.getter(name="secondaryColorHex")
    def secondary_color_hex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secondary color hex code
        """
        return pulumi.get(self, "secondary_color_hex")

    @secondary_color_hex.setter
    def secondary_color_hex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secondary_color_hex", value)

    @_builtins.property
    @pulumi.getter(name="signInPageTouchPointVariant")
    def sign_in_page_touch_point_variant(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "sign_in_page_touch_point_variant")

    @sign_in_page_touch_point_variant.setter
    def sign_in_page_touch_point_variant(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sign_in_page_touch_point_variant", value)

    @_builtins.property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        return pulumi.get(self, "theme_id")

    @theme_id.setter
    def theme_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "theme_id", value)


@pulumi.type_token("okta:index/theme:Theme")
class Theme(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 background_image: Optional[pulumi.Input[_builtins.str]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 favicon: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 theme_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Gets, updates, a single Theme of a Brand of an Okta Organization.

        This resource allows you to get and update an Okta
        [Theme](https://developer.okta.com/docs/reference/api/brands/#theme-object).

        The Okta Management API does not have a true Create or Delete for a theme. Therefore, the theme resource must be imported
        first into the pulumi state before updates can be applied to the theme.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.get_brands()
        # resource has been imported into current state:
        # $ terraform import okta_theme.example <theme id>
        example = okta.Theme("example",
            brand_id=test.brands[0].id,
            logo="path/to/logo.png",
            favicon="path/to/favicon.png",
            background_image="path/to/background.png",
            primary_color_hex="#1662dd",
            secondary_color_hex="#ebebed",
            sign_in_page_touch_point_variant="OKTA_DEFAULT",
            end_user_dashboard_touch_point_variant="OKTA_DEFAULT",
            error_page_touch_point_variant="OKTA_DEFAULT",
            email_template_touch_point_variant="OKTA_DEFAULT")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/theme:Theme example <brand_id>/<theme_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] background_image: Path to local file
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] email_template_touch_point_variant: Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[_builtins.str] end_user_dashboard_touch_point_variant: Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[_builtins.str] error_page_touch_point_variant: Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] favicon: Path to local file
        :param pulumi.Input[_builtins.str] logo: Path to local file
        :param pulumi.Input[_builtins.str] primary_color_contrast_hex: Primary color contrast hex code
        :param pulumi.Input[_builtins.str] primary_color_hex: Primary color hex code
        :param pulumi.Input[_builtins.str] secondary_color_contrast_hex: Secondary color contrast hex code
        :param pulumi.Input[_builtins.str] secondary_color_hex: Secondary color hex code
        :param pulumi.Input[_builtins.str] sign_in_page_touch_point_variant: Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] theme_id: Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ThemeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Gets, updates, a single Theme of a Brand of an Okta Organization.

        This resource allows you to get and update an Okta
        [Theme](https://developer.okta.com/docs/reference/api/brands/#theme-object).

        The Okta Management API does not have a true Create or Delete for a theme. Therefore, the theme resource must be imported
        first into the pulumi state before updates can be applied to the theme.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test = okta.get_brands()
        # resource has been imported into current state:
        # $ terraform import okta_theme.example <theme id>
        example = okta.Theme("example",
            brand_id=test.brands[0].id,
            logo="path/to/logo.png",
            favicon="path/to/favicon.png",
            background_image="path/to/background.png",
            primary_color_hex="#1662dd",
            secondary_color_hex="#ebebed",
            sign_in_page_touch_point_variant="OKTA_DEFAULT",
            end_user_dashboard_touch_point_variant="OKTA_DEFAULT",
            error_page_touch_point_variant="OKTA_DEFAULT",
            email_template_touch_point_variant="OKTA_DEFAULT")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/theme:Theme example <brand_id>/<theme_id>
        ```

        :param str resource_name: The name of the resource.
        :param ThemeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ThemeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 background_image: Optional[pulumi.Input[_builtins.str]] = None,
                 brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                 email_template_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 end_user_dashboard_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 error_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 favicon: Optional[pulumi.Input[_builtins.str]] = None,
                 logo: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 primary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 secondary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
                 sign_in_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
                 theme_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ThemeArgs.__new__(ThemeArgs)

            __props__.__dict__["background_image"] = background_image
            if brand_id is None and not opts.urn:
                raise TypeError("Missing required property 'brand_id'")
            __props__.__dict__["brand_id"] = brand_id
            __props__.__dict__["email_template_touch_point_variant"] = email_template_touch_point_variant
            __props__.__dict__["end_user_dashboard_touch_point_variant"] = end_user_dashboard_touch_point_variant
            __props__.__dict__["error_page_touch_point_variant"] = error_page_touch_point_variant
            __props__.__dict__["favicon"] = favicon
            __props__.__dict__["logo"] = logo
            __props__.__dict__["primary_color_contrast_hex"] = primary_color_contrast_hex
            __props__.__dict__["primary_color_hex"] = primary_color_hex
            __props__.__dict__["secondary_color_contrast_hex"] = secondary_color_contrast_hex
            __props__.__dict__["secondary_color_hex"] = secondary_color_hex
            __props__.__dict__["sign_in_page_touch_point_variant"] = sign_in_page_touch_point_variant
            __props__.__dict__["theme_id"] = theme_id
            __props__.__dict__["background_image_url"] = None
            __props__.__dict__["favicon_url"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["logo_url"] = None
        super(Theme, __self__).__init__(
            'okta:index/theme:Theme',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            background_image: Optional[pulumi.Input[_builtins.str]] = None,
            background_image_url: Optional[pulumi.Input[_builtins.str]] = None,
            brand_id: Optional[pulumi.Input[_builtins.str]] = None,
            email_template_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
            end_user_dashboard_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
            error_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
            favicon: Optional[pulumi.Input[_builtins.str]] = None,
            favicon_url: Optional[pulumi.Input[_builtins.str]] = None,
            links: Optional[pulumi.Input[_builtins.str]] = None,
            logo: Optional[pulumi.Input[_builtins.str]] = None,
            logo_url: Optional[pulumi.Input[_builtins.str]] = None,
            primary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
            primary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
            secondary_color_contrast_hex: Optional[pulumi.Input[_builtins.str]] = None,
            secondary_color_hex: Optional[pulumi.Input[_builtins.str]] = None,
            sign_in_page_touch_point_variant: Optional[pulumi.Input[_builtins.str]] = None,
            theme_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Theme':
        """
        Get an existing Theme resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] background_image: Path to local file
        :param pulumi.Input[_builtins.str] background_image_url: Background image URL
        :param pulumi.Input[_builtins.str] brand_id: Brand ID
        :param pulumi.Input[_builtins.str] email_template_touch_point_variant: Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        :param pulumi.Input[_builtins.str] end_user_dashboard_touch_point_variant: Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        :param pulumi.Input[_builtins.str] error_page_touch_point_variant: Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] favicon: Path to local file
        :param pulumi.Input[_builtins.str] favicon_url: Favicon URL
        :param pulumi.Input[_builtins.str] links: Link relations for this object - JSON HAL - Discoverable resources related to the email template
        :param pulumi.Input[_builtins.str] logo: Path to local file
        :param pulumi.Input[_builtins.str] logo_url: Logo URL
        :param pulumi.Input[_builtins.str] primary_color_contrast_hex: Primary color contrast hex code
        :param pulumi.Input[_builtins.str] primary_color_hex: Primary color hex code
        :param pulumi.Input[_builtins.str] secondary_color_contrast_hex: Secondary color contrast hex code
        :param pulumi.Input[_builtins.str] secondary_color_hex: Secondary color hex code
        :param pulumi.Input[_builtins.str] sign_in_page_touch_point_variant: Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        :param pulumi.Input[_builtins.str] theme_id: Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ThemeState.__new__(_ThemeState)

        __props__.__dict__["background_image"] = background_image
        __props__.__dict__["background_image_url"] = background_image_url
        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["email_template_touch_point_variant"] = email_template_touch_point_variant
        __props__.__dict__["end_user_dashboard_touch_point_variant"] = end_user_dashboard_touch_point_variant
        __props__.__dict__["error_page_touch_point_variant"] = error_page_touch_point_variant
        __props__.__dict__["favicon"] = favicon
        __props__.__dict__["favicon_url"] = favicon_url
        __props__.__dict__["links"] = links
        __props__.__dict__["logo"] = logo
        __props__.__dict__["logo_url"] = logo_url
        __props__.__dict__["primary_color_contrast_hex"] = primary_color_contrast_hex
        __props__.__dict__["primary_color_hex"] = primary_color_hex
        __props__.__dict__["secondary_color_contrast_hex"] = secondary_color_contrast_hex
        __props__.__dict__["secondary_color_hex"] = secondary_color_hex
        __props__.__dict__["sign_in_page_touch_point_variant"] = sign_in_page_touch_point_variant
        __props__.__dict__["theme_id"] = theme_id
        return Theme(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backgroundImage")
    def background_image(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "background_image")

    @_builtins.property
    @pulumi.getter(name="backgroundImageUrl")
    def background_image_url(self) -> pulumi.Output[_builtins.str]:
        """
        Background image URL
        """
        return pulumi.get(self, "background_image_url")

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Output[_builtins.str]:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="emailTemplateTouchPointVariant")
    def email_template_touch_point_variant(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Variant for email templates (`OKTA_DEFAULT`, `FULL_THEME`)
        """
        return pulumi.get(self, "email_template_touch_point_variant")

    @_builtins.property
    @pulumi.getter(name="endUserDashboardTouchPointVariant")
    def end_user_dashboard_touch_point_variant(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Variant for the Okta End-User Dashboard (`OKTA_DEFAULT`, `WHITE_LOGO_BACKGROUND`, `FULL_THEME`, `LOGO_ON_FULL_WHITE_BACKGROUND`)
        """
        return pulumi.get(self, "end_user_dashboard_touch_point_variant")

    @_builtins.property
    @pulumi.getter(name="errorPageTouchPointVariant")
    def error_page_touch_point_variant(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Variant for the error page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "error_page_touch_point_variant")

    @_builtins.property
    @pulumi.getter
    def favicon(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "favicon")

    @_builtins.property
    @pulumi.getter(name="faviconUrl")
    def favicon_url(self) -> pulumi.Output[_builtins.str]:
        """
        Favicon URL
        """
        return pulumi.get(self, "favicon_url")

    @_builtins.property
    @pulumi.getter
    def links(self) -> pulumi.Output[_builtins.str]:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the email template
        """
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def logo(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to local file
        """
        return pulumi.get(self, "logo")

    @_builtins.property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> pulumi.Output[_builtins.str]:
        """
        Logo URL
        """
        return pulumi.get(self, "logo_url")

    @_builtins.property
    @pulumi.getter(name="primaryColorContrastHex")
    def primary_color_contrast_hex(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Primary color contrast hex code
        """
        return pulumi.get(self, "primary_color_contrast_hex")

    @_builtins.property
    @pulumi.getter(name="primaryColorHex")
    def primary_color_hex(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Primary color hex code
        """
        return pulumi.get(self, "primary_color_hex")

    @_builtins.property
    @pulumi.getter(name="secondaryColorContrastHex")
    def secondary_color_contrast_hex(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Secondary color contrast hex code
        """
        return pulumi.get(self, "secondary_color_contrast_hex")

    @_builtins.property
    @pulumi.getter(name="secondaryColorHex")
    def secondary_color_hex(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Secondary color hex code
        """
        return pulumi.get(self, "secondary_color_hex")

    @_builtins.property
    @pulumi.getter(name="signInPageTouchPointVariant")
    def sign_in_page_touch_point_variant(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Variant for the Okta Sign-In Page (`OKTA_DEFAULT`, `BACKGROUND_SECONDARY_COLOR`, `BACKGROUND_IMAGE`)
        """
        return pulumi.get(self, "sign_in_page_touch_point_variant")

    @_builtins.property
    @pulumi.getter(name="themeId")
    def theme_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Theme ID - Note: Okta API for theme only reads and updates therefore the okta*theme resource needs to act as a quasi data source. Do this by setting theme*id.
        """
        return pulumi.get(self, "theme_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TokenArgs', 'Token']

@pulumi.input_type
class TokenArgs:
    def __init__(__self__, *,
                 client_id: pulumi.Input[_builtins.str],
                 id_property: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a Token resource.
        :param pulumi.Input[_builtins.str] client_id: The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        :param pulumi.Input[_builtins.str] id_property: The unique Okta ID of the refresh token.
        """
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "id_property", id_property)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        The unique Okta ID of the refresh token.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)


@pulumi.input_type
class _TokenState:
    def __init__(__self__, *,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Token resources.
        :param pulumi.Input[_builtins.str] client_id: The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        :param pulumi.Input[_builtins.str] id_property: The unique Okta ID of the refresh token.
        :param pulumi.Input[_builtins.str] status: The current status of the token (e.g., `ACTIVE`, `REVOKED`).
        :param pulumi.Input[_builtins.str] user_id: The unique Okta ID of the user associated with this token.
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique Okta ID of the refresh token.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The current status of the token (e.g., `ACTIVE`, `REVOKED`).
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique Okta ID of the user associated with this token.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("okta:app/token:Token")
class Token(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Import and Manage Existing Token

        ```python
        import pulumi
        import pulumi_okta as okta

        # Import an existing refresh token
        example = okta.app.Token("example",
            client_id="0oardd5r32PWsF4421d7",
            id_property="oar1godmqw4QUiX4C1d7")
        ```

        ## Import

        Refresh tokens can be imported using the format `{client_id}/{token_id}`:

        bash

        ```sh
        $ pulumi import okta:app/token:Token example 0oardd5r32PWsF4421d7/oar1godmqw4QUiX4C1d7
        ```

        Where:

        - `0oardd5r32PWsF4421d7` is the application's client_id

        - `oar1godmqw4QUiX4C1d7` is the Refresh token ID

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        :param pulumi.Input[_builtins.str] id_property: The unique Okta ID of the refresh token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Import and Manage Existing Token

        ```python
        import pulumi
        import pulumi_okta as okta

        # Import an existing refresh token
        example = okta.app.Token("example",
            client_id="0oardd5r32PWsF4421d7",
            id_property="oar1godmqw4QUiX4C1d7")
        ```

        ## Import

        Refresh tokens can be imported using the format `{client_id}/{token_id}`:

        bash

        ```sh
        $ pulumi import okta:app/token:Token example 0oardd5r32PWsF4421d7/oar1godmqw4QUiX4C1d7
        ```

        Where:

        - `0oardd5r32PWsF4421d7` is the application's client_id

        - `oar1godmqw4QUiX4C1d7` is the Refresh token ID

        :param str resource_name: The name of the resource.
        :param TokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TokenArgs.__new__(TokenArgs)

            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            __props__.__dict__["status"] = None
            __props__.__dict__["user_id"] = None
        super(Token, __self__).__init__(
            'okta:app/token:Token',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_id: Optional[pulumi.Input[_builtins.str]] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Token':
        """
        Get an existing Token resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] client_id: The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        :param pulumi.Input[_builtins.str] id_property: The unique Okta ID of the refresh token.
        :param pulumi.Input[_builtins.str] status: The current status of the token (e.g., `ACTIVE`, `REVOKED`).
        :param pulumi.Input[_builtins.str] user_id: The unique Okta ID of the user associated with this token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TokenState.__new__(_TokenState)

        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["status"] = status
        __props__.__dict__["user_id"] = user_id
        return Token(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique Okta ID of the application associated with this token. This is typically the `client_id` of an refresh application.
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        The unique Okta ID of the refresh token.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The current status of the token (e.g., `ACTIVE`, `REVOKED`).
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique Okta ID of the user associated with this token.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEntitlementResult',
    'AwaitableGetEntitlementResult',
    'get_entitlement',
    'get_entitlement_output',
]

@pulumi.output_type
class GetEntitlementResult:
    """
    A collection of values returned by getEntitlement.
    """
    def __init__(__self__, data_type=None, external_value=None, id=None, multi_value=None, name=None, parent=None, parent_resource_orn=None, values=None):
        if data_type and not isinstance(data_type, str):
            raise TypeError("Expected argument 'data_type' to be a str")
        pulumi.set(__self__, "data_type", data_type)
        if external_value and not isinstance(external_value, str):
            raise TypeError("Expected argument 'external_value' to be a str")
        pulumi.set(__self__, "external_value", external_value)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if multi_value and not isinstance(multi_value, bool):
            raise TypeError("Expected argument 'multi_value' to be a bool")
        pulumi.set(__self__, "multi_value", multi_value)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent and not isinstance(parent, dict):
            raise TypeError("Expected argument 'parent' to be a dict")
        pulumi.set(__self__, "parent", parent)
        if parent_resource_orn and not isinstance(parent_resource_orn, str):
            raise TypeError("Expected argument 'parent_resource_orn' to be a str")
        pulumi.set(__self__, "parent_resource_orn", parent_resource_orn)
        if values and not isinstance(values, list):
            raise TypeError("Expected argument 'values' to be a list")
        pulumi.set(__self__, "values", values)

    @_builtins.property
    @pulumi.getter(name="dataType")
    def data_type(self) -> _builtins.str:
        return pulumi.get(self, "data_type")

    @_builtins.property
    @pulumi.getter(name="externalValue")
    def external_value(self) -> _builtins.str:
        return pulumi.get(self, "external_value")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="multiValue")
    def multi_value(self) -> _builtins.bool:
        return pulumi.get(self, "multi_value")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional['outputs.GetEntitlementParentResult']:
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="parentResourceOrn")
    def parent_resource_orn(self) -> _builtins.str:
        return pulumi.get(self, "parent_resource_orn")

    @_builtins.property
    @pulumi.getter
    def values(self) -> Optional[Sequence['outputs.GetEntitlementValueResult']]:
        return pulumi.get(self, "values")


class AwaitableGetEntitlementResult(GetEntitlementResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEntitlementResult(
            data_type=self.data_type,
            external_value=self.external_value,
            id=self.id,
            multi_value=self.multi_value,
            name=self.name,
            parent=self.parent,
            parent_resource_orn=self.parent_resource_orn,
            values=self.values)


def get_entitlement(id: Optional[_builtins.str] = None,
                    parent: Optional[Union['GetEntitlementParentArgs', 'GetEntitlementParentArgsDict']] = None,
                    values: Optional[Sequence[Union['GetEntitlementValueArgs', 'GetEntitlementValueArgsDict']]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEntitlementResult:
    """
    Get the entitlement belonging to an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_entitlement(id="<entitlement id>")
    ```


    :param _builtins.str id: The ID of this resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['parent'] = parent
    __args__['values'] = values
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getEntitlement:getEntitlement', __args__, opts=opts, typ=GetEntitlementResult).value

    return AwaitableGetEntitlementResult(
        data_type=pulumi.get(__ret__, 'data_type'),
        external_value=pulumi.get(__ret__, 'external_value'),
        id=pulumi.get(__ret__, 'id'),
        multi_value=pulumi.get(__ret__, 'multi_value'),
        name=pulumi.get(__ret__, 'name'),
        parent=pulumi.get(__ret__, 'parent'),
        parent_resource_orn=pulumi.get(__ret__, 'parent_resource_orn'),
        values=pulumi.get(__ret__, 'values'))
def get_entitlement_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                           parent: Optional[pulumi.Input[Optional[Union['GetEntitlementParentArgs', 'GetEntitlementParentArgsDict']]]] = None,
                           values: Optional[pulumi.Input[Optional[Sequence[Union['GetEntitlementValueArgs', 'GetEntitlementValueArgsDict']]]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEntitlementResult]:
    """
    Get the entitlement belonging to an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_entitlement(id="<entitlement id>")
    ```


    :param _builtins.str id: The ID of this resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['parent'] = parent
    __args__['values'] = values
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getEntitlement:getEntitlement', __args__, opts=opts, typ=GetEntitlementResult)
    return __ret__.apply(lambda __response__: GetEntitlementResult(
        data_type=pulumi.get(__response__, 'data_type'),
        external_value=pulumi.get(__response__, 'external_value'),
        id=pulumi.get(__response__, 'id'),
        multi_value=pulumi.get(__response__, 'multi_value'),
        name=pulumi.get(__response__, 'name'),
        parent=pulumi.get(__response__, 'parent'),
        parent_resource_orn=pulumi.get(__response__, 'parent_resource_orn'),
        values=pulumi.get(__response__, 'values')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOidcResult',
    'AwaitableGetOidcResult',
    'get_oidc',
    'get_oidc_output',
]

@pulumi.output_type
class GetOidcResult:
    """
    A collection of values returned by getOidc.
    """
    def __init__(__self__, authorization_binding=None, authorization_url=None, client_id=None, client_secret=None, id=None, issuer_mode=None, issuer_url=None, jwks_binding=None, jwks_url=None, max_clock_skew=None, name=None, protocol_type=None, scopes=None, token_binding=None, token_url=None, type=None, user_info_binding=None, user_info_url=None):
        if authorization_binding and not isinstance(authorization_binding, str):
            raise TypeError("Expected argument 'authorization_binding' to be a str")
        pulumi.set(__self__, "authorization_binding", authorization_binding)
        if authorization_url and not isinstance(authorization_url, str):
            raise TypeError("Expected argument 'authorization_url' to be a str")
        pulumi.set(__self__, "authorization_url", authorization_url)
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if client_secret and not isinstance(client_secret, str):
            raise TypeError("Expected argument 'client_secret' to be a str")
        pulumi.set(__self__, "client_secret", client_secret)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer_mode and not isinstance(issuer_mode, str):
            raise TypeError("Expected argument 'issuer_mode' to be a str")
        pulumi.set(__self__, "issuer_mode", issuer_mode)
        if issuer_url and not isinstance(issuer_url, str):
            raise TypeError("Expected argument 'issuer_url' to be a str")
        pulumi.set(__self__, "issuer_url", issuer_url)
        if jwks_binding and not isinstance(jwks_binding, str):
            raise TypeError("Expected argument 'jwks_binding' to be a str")
        pulumi.set(__self__, "jwks_binding", jwks_binding)
        if jwks_url and not isinstance(jwks_url, str):
            raise TypeError("Expected argument 'jwks_url' to be a str")
        pulumi.set(__self__, "jwks_url", jwks_url)
        if max_clock_skew and not isinstance(max_clock_skew, int):
            raise TypeError("Expected argument 'max_clock_skew' to be a int")
        pulumi.set(__self__, "max_clock_skew", max_clock_skew)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if protocol_type and not isinstance(protocol_type, str):
            raise TypeError("Expected argument 'protocol_type' to be a str")
        pulumi.set(__self__, "protocol_type", protocol_type)
        if scopes and not isinstance(scopes, list):
            raise TypeError("Expected argument 'scopes' to be a list")
        pulumi.set(__self__, "scopes", scopes)
        if token_binding and not isinstance(token_binding, str):
            raise TypeError("Expected argument 'token_binding' to be a str")
        pulumi.set(__self__, "token_binding", token_binding)
        if token_url and not isinstance(token_url, str):
            raise TypeError("Expected argument 'token_url' to be a str")
        pulumi.set(__self__, "token_url", token_url)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if user_info_binding and not isinstance(user_info_binding, str):
            raise TypeError("Expected argument 'user_info_binding' to be a str")
        pulumi.set(__self__, "user_info_binding", user_info_binding)
        if user_info_url and not isinstance(user_info_url, str):
            raise TypeError("Expected argument 'user_info_url' to be a str")
        pulumi.set(__self__, "user_info_url", user_info_url)

    @_builtins.property
    @pulumi.getter(name="authorizationBinding")
    def authorization_binding(self) -> _builtins.str:
        """
        The method of making an authorization request.
        """
        return pulumi.get(self, "authorization_binding")

    @_builtins.property
    @pulumi.getter(name="authorizationUrl")
    def authorization_url(self) -> _builtins.str:
        """
        IdP Authorization Server (AS) endpoint to request consent from the user and obtain an authorization code grant.
        """
        return pulumi.get(self, "authorization_url")

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> _builtins.str:
        """
        Unique identifier issued by AS for the Okta IdP instance.
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> _builtins.str:
        """
        Client secret issued by AS for the Okta IdP instance.
        """
        return pulumi.get(self, "client_secret")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Id of idp.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="issuerMode")
    def issuer_mode(self) -> _builtins.str:
        """
        Indicates whether Okta uses the original Okta org domain URL, a custom domain URL, or dynamic.
        """
        return pulumi.get(self, "issuer_mode")

    @_builtins.property
    @pulumi.getter(name="issuerUrl")
    def issuer_url(self) -> _builtins.str:
        """
        URI that identifies the issuer.
        """
        return pulumi.get(self, "issuer_url")

    @_builtins.property
    @pulumi.getter(name="jwksBinding")
    def jwks_binding(self) -> _builtins.str:
        """
        The method of making a request for the OIDC JWKS.
        """
        return pulumi.get(self, "jwks_binding")

    @_builtins.property
    @pulumi.getter(name="jwksUrl")
    def jwks_url(self) -> _builtins.str:
        """
        Endpoint where the keys signer publishes its keys in a JWK Set.
        """
        return pulumi.get(self, "jwks_url")

    @_builtins.property
    @pulumi.getter(name="maxClockSkew")
    def max_clock_skew(self) -> _builtins.int:
        """
        Maximum allowable clock-skew when processing messages from the IdP.
        """
        return pulumi.get(self, "max_clock_skew")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the idp.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> _builtins.str:
        """
        The type of protocol to use.
        """
        return pulumi.get(self, "protocol_type")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Sequence[_builtins.str]:
        """
        The scopes of the IdP.
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter(name="tokenBinding")
    def token_binding(self) -> _builtins.str:
        """
        The method of making a token request.
        """
        return pulumi.get(self, "token_binding")

    @_builtins.property
    @pulumi.getter(name="tokenUrl")
    def token_url(self) -> _builtins.str:
        """
        IdP Authorization Server (AS) endpoint to exchange the authorization code grant for an access token.
        """
        return pulumi.get(self, "token_url")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of idp.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="userInfoBinding")
    def user_info_binding(self) -> _builtins.str:
        """
        The method of making a user info request.
        """
        return pulumi.get(self, "user_info_binding")

    @_builtins.property
    @pulumi.getter(name="userInfoUrl")
    def user_info_url(self) -> _builtins.str:
        """
        Protected resource endpoint that returns claims about the authenticated user.
        """
        return pulumi.get(self, "user_info_url")


class AwaitableGetOidcResult(GetOidcResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOidcResult(
            authorization_binding=self.authorization_binding,
            authorization_url=self.authorization_url,
            client_id=self.client_id,
            client_secret=self.client_secret,
            id=self.id,
            issuer_mode=self.issuer_mode,
            issuer_url=self.issuer_url,
            jwks_binding=self.jwks_binding,
            jwks_url=self.jwks_url,
            max_clock_skew=self.max_clock_skew,
            name=self.name,
            protocol_type=self.protocol_type,
            scopes=self.scopes,
            token_binding=self.token_binding,
            token_url=self.token_url,
            type=self.type,
            user_info_binding=self.user_info_binding,
            user_info_url=self.user_info_url)


def get_oidc(id: Optional[_builtins.str] = None,
             name: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOidcResult:
    """
    Get a OIDC IdP from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.idp.get_oidc(name="Example Provider")
    ```


    :param _builtins.str id: Id of idp.
    :param _builtins.str name: Name of the idp.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:idp/getOidc:getOidc', __args__, opts=opts, typ=GetOidcResult).value

    return AwaitableGetOidcResult(
        authorization_binding=pulumi.get(__ret__, 'authorization_binding'),
        authorization_url=pulumi.get(__ret__, 'authorization_url'),
        client_id=pulumi.get(__ret__, 'client_id'),
        client_secret=pulumi.get(__ret__, 'client_secret'),
        id=pulumi.get(__ret__, 'id'),
        issuer_mode=pulumi.get(__ret__, 'issuer_mode'),
        issuer_url=pulumi.get(__ret__, 'issuer_url'),
        jwks_binding=pulumi.get(__ret__, 'jwks_binding'),
        jwks_url=pulumi.get(__ret__, 'jwks_url'),
        max_clock_skew=pulumi.get(__ret__, 'max_clock_skew'),
        name=pulumi.get(__ret__, 'name'),
        protocol_type=pulumi.get(__ret__, 'protocol_type'),
        scopes=pulumi.get(__ret__, 'scopes'),
        token_binding=pulumi.get(__ret__, 'token_binding'),
        token_url=pulumi.get(__ret__, 'token_url'),
        type=pulumi.get(__ret__, 'type'),
        user_info_binding=pulumi.get(__ret__, 'user_info_binding'),
        user_info_url=pulumi.get(__ret__, 'user_info_url'))
def get_oidc_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOidcResult]:
    """
    Get a OIDC IdP from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.idp.get_oidc(name="Example Provider")
    ```


    :param _builtins.str id: Id of idp.
    :param _builtins.str name: Name of the idp.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:idp/getOidc:getOidc', __args__, opts=opts, typ=GetOidcResult)
    return __ret__.apply(lambda __response__: GetOidcResult(
        authorization_binding=pulumi.get(__response__, 'authorization_binding'),
        authorization_url=pulumi.get(__response__, 'authorization_url'),
        client_id=pulumi.get(__response__, 'client_id'),
        client_secret=pulumi.get(__response__, 'client_secret'),
        id=pulumi.get(__response__, 'id'),
        issuer_mode=pulumi.get(__response__, 'issuer_mode'),
        issuer_url=pulumi.get(__response__, 'issuer_url'),
        jwks_binding=pulumi.get(__response__, 'jwks_binding'),
        jwks_url=pulumi.get(__response__, 'jwks_url'),
        max_clock_skew=pulumi.get(__response__, 'max_clock_skew'),
        name=pulumi.get(__response__, 'name'),
        protocol_type=pulumi.get(__response__, 'protocol_type'),
        scopes=pulumi.get(__response__, 'scopes'),
        token_binding=pulumi.get(__response__, 'token_binding'),
        token_url=pulumi.get(__response__, 'token_url'),
        type=pulumi.get(__response__, 'type'),
        user_info_binding=pulumi.get(__response__, 'user_info_binding'),
        user_info_url=pulumi.get(__response__, 'user_info_url')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['HookKeyArgs', 'HookKey']

@pulumi.input_type
class HookKeyArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a HookKey resource.
        :param pulumi.Input[_builtins.str] name: Display name for the key. Must be between 1 and 255 characters.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Display name for the key. Must be between 1 and 255 characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _HookKeyState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 is_used: Optional[pulumi.Input[_builtins.bool]] = None,
                 key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering HookKey resources.
        :param pulumi.Input[_builtins.str] created: Timestamp when the key was created.
        :param pulumi.Input[_builtins.bool] is_used: Whether this key is currently in use by other applications.
        :param pulumi.Input[_builtins.str] key_id: The alias of the public key.
        :param pulumi.Input[_builtins.str] last_updated: Timestamp when the key was updated.
        :param pulumi.Input[_builtins.str] name: Display name for the key. Must be between 1 and 255 characters.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if is_used is not None:
            pulumi.set(__self__, "is_used", is_used)
        if key_id is not None:
            pulumi.set(__self__, "key_id", key_id)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp when the key was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="isUsed")
    def is_used(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this key is currently in use by other applications.
        """
        return pulumi.get(self, "is_used")

    @is_used.setter
    def is_used(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_used", value)

    @_builtins.property
    @pulumi.getter(name="keyId")
    def key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The alias of the public key.
        """
        return pulumi.get(self, "key_id")

    @key_id.setter
    def key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key_id", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp when the key was updated.
        """
        return pulumi.get(self, "last_updated")

    @last_updated.setter
    def last_updated(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Display name for the key. Must be between 1 and 255 characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("okta:index/hookKey:HookKey")
class HookKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages a Hook Key. This resource allows you to create and configure an Okta [Hook Key](https://developer.okta.com/docs/reference/api/hook-keys/).

        Use Key Management to create and manage JSON Web Keys (JWKS) that support OAuth 2.0 client authentication. The key is composed of a public and private key pair. The private key signs the JSON Web Token (JWT) and the public key validates it on the client side.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.HookKey("example", name="My Hook Key")
        ```

        ## Import

        Hook Keys can be imported using the `id`.

        ```sh
        $ pulumi import okta:index/hookKey:HookKey example &#60;hook_key_id&#62;
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: Display name for the key. Must be between 1 and 255 characters.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[HookKeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages a Hook Key. This resource allows you to create and configure an Okta [Hook Key](https://developer.okta.com/docs/reference/api/hook-keys/).

        Use Key Management to create and manage JSON Web Keys (JWKS) that support OAuth 2.0 client authentication. The key is composed of a public and private key pair. The private key signs the JSON Web Token (JWT) and the public key validates it on the client side.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.HookKey("example", name="My Hook Key")
        ```

        ## Import

        Hook Keys can be imported using the `id`.

        ```sh
        $ pulumi import okta:index/hookKey:HookKey example &#60;hook_key_id&#62;
        ```

        :param str resource_name: The name of the resource.
        :param HookKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HookKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HookKeyArgs.__new__(HookKeyArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["created"] = None
            __props__.__dict__["is_used"] = None
            __props__.__dict__["key_id"] = None
            __props__.__dict__["last_updated"] = None
        super(HookKey, __self__).__init__(
            'okta:index/hookKey:HookKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            is_used: Optional[pulumi.Input[_builtins.bool]] = None,
            key_id: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'HookKey':
        """
        Get an existing HookKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created: Timestamp when the key was created.
        :param pulumi.Input[_builtins.bool] is_used: Whether this key is currently in use by other applications.
        :param pulumi.Input[_builtins.str] key_id: The alias of the public key.
        :param pulumi.Input[_builtins.str] last_updated: Timestamp when the key was updated.
        :param pulumi.Input[_builtins.str] name: Display name for the key. Must be between 1 and 255 characters.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HookKeyState.__new__(_HookKeyState)

        __props__.__dict__["created"] = created
        __props__.__dict__["is_used"] = is_used
        __props__.__dict__["key_id"] = key_id
        __props__.__dict__["last_updated"] = last_updated
        __props__.__dict__["name"] = name
        return HookKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp when the key was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="isUsed")
    def is_used(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether this key is currently in use by other applications.
        """
        return pulumi.get(self, "is_used")

    @_builtins.property
    @pulumi.getter(name="keyId")
    def key_id(self) -> pulumi.Output[_builtins.str]:
        """
        The alias of the public key.
        """
        return pulumi.get(self, "key_id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp when the key was updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Display name for the key. Must be between 1 and 255 characters.
        """
        return pulumi.get(self, "name")

